==> qt5-style-kvantum_0.11.1+repack.orig.tar.xz: Kvantum-0.11.1/README.md <==
# Kvantum

## Overview

Kvantum (by Pedram Pourang, a.k.a. Tsu Jan <tsujan2000@gmail.com>) is an SVG-based theme engine for Qt, tuned to KDE and LXQt, with an emphasis on elegance, usability and practicality. Its homepage is <https://github.com/tsujan/Kvantum>.

Kvantum has a default dark theme, which is inspired by the default theme of Enlightenment. Creation of realistic themes like that for KDE was my first reason to make Kvantum but it goes far beyond its default theme: you could make themes with very different looks and feels for it, whether they be photorealistic or cartoonish, 3D or flat, embellished or minimalistic, or something in between, and Kvantum will let you control almost every aspect of Qt widgets.

Kvantum also comes with extra themes that are installed as root with Qt5 installation and can be selected and activated by using Kvantum Manager.

Please see INSTALL for instructions on compilation, installation and usage!

For instructions on how to change configuration or make new themes, read the files Theme-Config and Theme-Making in the "doc" folder!


## Credits:

The core idea of Kvantum, namely using of SVG images for drawing Qt widgets, is taken from QuantumStyle (not developed anymore but continued as QSvgStyle at https://github.com/DexterMagnific/QSvgStyle).

Some code parts are adapted from:

QtCurve (https://projects.kde.org/projects/playground/artwork/qtcurve/repository)

Oxygen (https://projects.kde.org/projects/playground/artwork/oxygen/repository)

Oxygen-Transparent (https://projects.kde.org/projects/playground/artwork/oxygen-transparent/repository)

Bespin (http://cloudcity.sourceforge.net/download.php)

My sincerest thanks go to all users whose bug reports, feature requests and suggestions have been crucial for improving Kvantum.

## Some Screenshots:

![Default](screenshots/Default.png?raw=true "Default")
![KvAmbience](screenshots/KvAmbience.png?raw=true "KvAmbience")
![KvBeige](screenshots/KvBeige.png?raw=true "KvBeige")
![KvGray](screenshots/KvGray.png?raw=true "KvGray")
![KvFlatLight](screenshots/KvFlatLight.png?raw=true "KvFlatLight")
![KvCurves3d](screenshots/KvCurves3d.png?raw=true "KvCurves3d")
![KvCurvesLight](screenshots/KvCurvesLight.png?raw=true "KvCurvesLight")
![KvGnomish](screenshots/KvGnomish.png?raw=true "KvGnomish")
![KvOxygen](screenshots/KvOxygen.png?raw=true "KvOxygen")
![KvSimplicityDark](screenshots/KvSimplicityDark.png?raw=true "KvSimplicityDark")
![KvSimplicityTurquoise](screenshots/KvSimplicityTurquoise.png?raw=true "KvSimplicityTurquoise")
![KvAdapta](screenshots/KvAdapta.png?raw=true "KvAdapta")

==> qt5-style-kvantum_0.14.1+repack.orig.tar.xz: Kvantum-0.14.1/README.md <==
# Kvantum

## Overview

Kvantum (by Pedram Pourang, a.k.a. Tsu Jan <tsujan2000@gmail.com>) is an SVG-based theme engine for Qt, tuned to KDE and LXQt, with an emphasis on elegance, usability and practicality. Its homepage is <https://github.com/tsujan/Kvantum>.

Kvantum has a default dark theme, which is inspired by the default theme of Enlightenment. Creation of realistic themes like that for KDE was my first reason to make Kvantum but it goes far beyond its default theme: you could make themes with very different looks and feels for it, whether they be photorealistic or cartoonish, 3D or flat, embellished or minimalistic, or something in between, and Kvantum will let you control almost every aspect of Qt widgets.

Kvantum also comes with extra themes that are installed as root with Qt5 installation and can be selected and activated by using Kvantum Manager.

Please see INSTALL for instructions on compilation, installation and usage!

For instructions on how to change configuration or make new themes, read the files Theme-Config and Theme-Making in the "doc" folder!


## Credits:

The core idea of Kvantum, namely using of SVG images for drawing Qt widgets, was taken from QuantumStyle (not developed anymore but continued as QSvgStyle at https://github.com/DexterMagnific/QSvgStyle).

Some code parts are adapted from:

QtCurve (https://projects.kde.org/projects/playground/artwork/qtcurve/repository)

Oxygen (https://projects.kde.org/projects/playground/artwork/oxygen/repository)

Oxygen-Transparent (https://projects.kde.org/projects/playground/artwork/oxygen-transparent/repository)

Bespin (http://cloudcity.sourceforge.net/download.php)

My sincerest thanks go to all users whose bug reports, feature requests and suggestions have been crucial for improving Kvantum.

## Some Screenshots:

![Default](screenshots/Default.png?raw=true "Default")
![KvAmbience](screenshots/KvAmbience.png?raw=true "KvAmbience")
![KvBeige](screenshots/KvBeige.png?raw=true "KvBeige")
![KvGray](screenshots/KvGray.png?raw=true "KvGray")
![KvFlatLight](screenshots/KvFlatLight.png?raw=true "KvFlatLight")
![KvCurves3d](screenshots/KvCurves3d.png?raw=true "KvCurves3d")
![KvCurvesLight](screenshots/KvCurvesLight.png?raw=true "KvCurvesLight")
![KvGnomish](screenshots/KvGnomish.png?raw=true "KvGnomish")
![KvOxygen](screenshots/KvOxygen.png?raw=true "KvOxygen")
![KvSimplicityDark](screenshots/KvSimplicityDark.png?raw=true "KvSimplicityDark")
![KvSimplicityTurquoise](screenshots/KvSimplicityTurquoise.png?raw=true "KvSimplicityTurquoise")
![KvAdapta](screenshots/KvAdapta.png?raw=true "KvAdapta")
